/*  smplayer2, GUI front-end for mplayer2.
    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "timeslider.h"

#include <QWheelEvent>
#include <QTimer>

#define DEBUG 0

TimeSlider::TimeSlider(QWidget *parent) : MySlider(parent)
{
    dont_update = FALSE;
    setMinimum(0);
#ifdef SEEKBAR_RESOLUTION
    setMaximum(SEEKBAR_RESOLUTION);
#else
    setMaximum(100);
#endif

    setFocusPolicy(Qt::NoFocus);
    setSizePolicy(QSizePolicy::Expanding , QSizePolicy::Fixed);

    connect(this, SIGNAL(sliderPressed()), this, SLOT(stopUpdate()));
    connect(this, SIGNAL(sliderReleased()), this, SLOT(resumeUpdate()));
    connect(this, SIGNAL(sliderReleased()), this, SLOT(mouseReleased()));
    connect(this, SIGNAL(valueChanged(int)), this, SLOT(valueChanged_slot(int)));
}

TimeSlider::~TimeSlider()
{
}

void TimeSlider::stopUpdate()
{
#if DEBUG
    qDebug("TimeSlider::stopUpdate");
#endif
    dont_update = TRUE;
}

void TimeSlider::resumeUpdate()
{
#if DEBUG
    qDebug("TimeSlider::resumeUpdate");
#endif
    dont_update = FALSE;
}

void TimeSlider::mouseReleased()
{
#if DEBUG
    qDebug("TimeSlider::mouseReleased");
#endif
    emit posChanged(value());
}

void TimeSlider::valueChanged_slot(int v)
{
#if DEBUG
    qDebug("TimeSlider::changedValue_slot: %d", v);
#endif

    // Only to make things clear:
    bool dragging = dont_update;

    if (!dragging) {
        if (v != position) {
#if DEBUG
            qDebug(" emitting posChanged");
#endif
            emit posChanged(v);
        }
    } else {
#if DEBUG
        qDebug(" emitting draggingPos");
#endif
        emit draggingPos(v);
    }
}

void TimeSlider::setPos(int v)
{
#if DEBUG
    qDebug("TimeSlider::setPos: %d", v);
    qDebug(" dont_update: %d", dont_update);
#endif

    if (v != pos()) {
        if (!dont_update) {
            position = v;
            setValue(v);
        }
    }
}

int TimeSlider::pos()
{
    return position;
}

void TimeSlider::wheelEvent(QWheelEvent *e)
{
    e->ignore();
}
